<?php
/**
 * Zikula Application Framework
 *
 * @copyright (c) 2009, Wendel Voigt <stuff@voigtworld.com>
 * @link http://code.zikula.org/bianor/
 * @version $Id: adminlinks.php 206 2009-12-28 22:48:09Z jusuff $
 * @license GNU/GPL - http://www.gnu.org/copyleft/gpl.html
 * @package menutree
 */

/**
 * Return list of admin modules
 *
 * Syntax used in menutree
 * {menutree:ext:adminlinks[:[flat,category]]}
 * Last param is optional.  It can be flat and/or category separated by a comma.
 * 'flat' will add the admin links in the current menu.  Without 'flat' the links are grouped one level down
 * 'category' additionally groups the admin links by their category.
 * You can combine 'flat' and 'category' to have the category links added in the current menu.
 *
 * @param array $args['item'] menu node to be replaced
 * @param string $args['lang'] current menu language
 * @param string $args['extrainfo'] additional params - if 'flat' then return links ungrouped. if 'category' module links grouped by category
 * @return mixed array of links if successful, false otherwise
 */
function menutree_externalapi_adminlinks($args)
{
    $item       = isset($args['item']) && !empty($args['item']) ? $args['item'] : null;
    $lang       = isset($args['lang']) && !empty($args['lang']) ? $args['lang'] : null;
    $extrainfo  = isset($args['extrainfo']) && !empty($args['extrainfo']) ? $args['extrainfo'] : null;
    // $item ang lang params are required
    if(!$item || !$lang) {
        return false;
    }

    // Convert extrainfo into flags
    $extrainfo = ($extrainfo) ? preg_split("/[\s]*,[\s]*/", trim($extrainfo)) : array();
    $flag = array();
    $flag['flat']     = in_array("flat",     $extrainfo);  //now true or false
    $flag['category'] = in_array("category", $extrainfo);  //now true or false

    // Make sure admin API is loaded   
    if (!pnModAPILoad('Admin','admin',true)) {
        return false;
    }

    if (!SecurityUtil::checkPermission('Admin::', "::", ACCESS_EDIT)) {
        return array(); // Since no permission, return empty links
    }

    // get id for first element, use api func to aviod id conflicts inside menu
    $idoffset = pnModAPIFunc('menutree','user','getidoffset',array('item' => $item['id']));
    $lineno = 0;

    $links = array();

    // if not flat, group the links into a single menu entry
    if (!$flag['flat']) {
        $links['adminlinks'] = array(
            $lang => array(
                'id' => $idoffset++,
                'name' => $item['name'],
                'href' => pnModURL('Admin', 'admin', 'adminpanel'),
                'title' => $item['title'],
                'className' => $item['className'],
                'state' => $item['state'],
                'lang' => $lang,
                'lineno' => $lineno++,
                'parent' => $item['parent']
            )
        );
    }

    // need to set parent node id - if links are grouped - use your_accont item id
    // otherwise parent id of replaced menu node
    $parentNode = (!$flag['flat']) ? $links['adminlinks'][$lang]['id'] : $item['parent'];

    // First work on the Admin module categories
    $catinfo  = array(); // used to store menu information for the categories
    $catlinks = array();

    if ($flag['category']){
        // Get all the Categories
        $categories = pnModAPIFunc('Admin', 'admin', 'getall');

        foreach ($categories as $item) {
            if (SecurityUtil::checkPermission('Admin::', "$item[catname]::$item[cid]", ACCESS_EDIT)) {
                // Set up the menu information for this category
                $catinfo[$item['cid']] = array (
                    'id' => $idoffset, // will need this to be a parent
                    'no' => 0          // start with 0 sub menu items
                );
                $catlinks[] = array(
                     $lang => array(
                        'id'        => $idoffset++,
                        'name'      => $item['catname'],
                        'href'      => pnModURL('Admin','admin','adminpanel', array('acid' => $item['cid'])),
                        'title'     => $item['description'],
                        'className' => '',
                        'state'     => 1,
                        'lang'      => $lang,
                        'lineno'    => $lineno++,
                        'parent'    => $parentNode
                    )
                );
            }
        }
    }

    // Now work on admin capable modules
    $adminmodules    = pnModGetAdminMods();
    $displayNameType = pnModGetVar('Admin', 'displaynametype', 1);
    $default_cid     = pnModGetVar('Admin', 'startcategory');
    $adminlinks      = array();

    foreach ($adminmodules as $adminmodule) {
        if (SecurityUtil::checkPermission("$adminmodule[name]::", '::', ACCESS_EDIT)) {
            $cid = pnModAPIFunc('Admin', 'admin', 'getmodcategory',
                                array('mid' => pnModGetIDFromName($adminmodule['name'])));
            $cid = (isset($catinfo[$cid])) ? $cid : $default_cid;  // make sure each module is assigned a category

            $modinfo = pnModGetInfo(pnModGetIDFromName($adminmodule['name']));

            if ($modinfo['type'] == 2 || $modinfo['type'] == 3) {
                $menutexturl = pnModURL($modinfo['name'], 'admin');
            } else {
                $menutexturl = 'admin.php?module=' . $modinfo['name'];
            }

            if ($displayNameType == 1) {
                $menutext = $modinfo['displayname'];
            } elseif ($displayNameType == 2) {
                $menutext = $modinfo['name'];
            } elseif ($displayNameType == 3) {
                $menutext = $modinfo['displayname'] . ' (' . $modinfo['name'] . ')';
            }

            $adminlinks[] = array(
                $lang => array(
                    'id'        => $idoffset++,
                    'name'      => $menutext,
                    'href'      => $menutexturl,
                    'title'     => $modinfo['description'],
                    'className' => '',
                    'state'     => 1,
                    'lang'      => $lang,
                    'lineno'    => ($flag['category']) ? $catinfo[$cid]['no']++ :$lineno++,
                    'parent'    => ($flag['category']) ? $catinfo[$cid]['id']   :$parentNode
                )
            );
        }
    }

    $links = array_merge($links, $catlinks, $adminlinks);

    return $links;

}
